#!/bin/bash
####################################
#
#
#      This  is  inv2l_0-1,  a skript that invokes and manages the M2L
#      manipulations. Read the documentation  in  the  README  and  in
#      [2l.tmac] first.
#        Section  [A] is a sequence of bash functions. These are invo-
#      ked in section [B]. Read through  part  [A]  and  decide  which
#      functions you want to invoke in part [B].
#
####################################>
#
#
#    <[A]> The Functions
#
#           {I} U_DIR
#           {II} MM_RENAME
#           {III} TEX_PREPROC
#           {IV} GROFF_INV
#           {V} LATEX_to_RTF
#
####################################>
#
#
#      <{I}> U_DIR
#
#      If  it  doesn't  exist yet, an [_] (underscore) subdirectory is
#      created. In order to keep the working directory clean, all out-
#      put is stuffed here. At this stage M2L creates 3 (three) output
#      files: file.m2l, file.tex and file.rtf.
#        If you want all output in the working directory,  comment  it
#      out  in  the "invokation" section ([B]) and set the [$OUT_PATH]
#      variable to [./].
#
####################################/
function U_DIR
    { # BEGIN FUNC
        if [ ! -d ./_/ ] ; then
        mkdir ./_/
        fi
    } # END FUNC
####################################\
#
#
#      <{II}> MM_RENAME
#
#      Input and output files have to be mapped to variables with the  pro-
#      per  endings.  All  input files have to be [*.mm] files, but you can
#      give a single file or all ([*.mm]) as arguments to [inv2l].
#
####################################/
function  MM_RENAME
    { # BEGIN FUNC
    M2LFILE=${IN_FILE%%.mm}.m2l
    TEXFILE=${IN_FILE%%.mm}.tex
    RTFFILE=${IN_FILE%%.mm}.rtf
    } # END FUNC
####################################\
#
#
#      <{III}> TEX_PREPROC
#
#      The IN_FILEs are preprocessed into *.m2l files. This means:
#        inserting the [.TEX]-[.tex] macros (as explained in [2l.tmac]);
#        replacing the inline escapes with appropriate LaTeX commands.
#
#      Output is a [.m2l] file in the [_] subdirectory.
#        This is the function that will need the most editing.  There  will
#      be more special signs like [\&] which have to be sed'ed.
#
#
####################################/
function TEX_PREPROC
    { # BEGIN FUNC
sed \
-e '1i\
.TEX' \
-e '$a\
.tex' \
-e '/^.po/d' \
-e 's/_/\\\\_/g' \
-e 's/\.bp/\\\\newpage/g' \
-e 's/\\fR/\\\\textrm{/g' \
-e 's/\\fB/\\\\textbf{/g' \
-e 's/\\fI/\\\\textit{/g' \
-e 's/\\f(BI/\\\\textbf{\\\\itshape /g' \
-e 's/\\fP/}/g' \
-e 's/\\&/\\\&/g' \
-e 's/\\\*F//g' \
    $1 > $2
    } # END FUNC
####################################\
#
#
#      <{IV}> GROFF_INV
#
#      Here  the processing takes place. For all input files, the [TEX_PRE-
#      PROC] function is called, and the resulting *.m2l  file  is  groffed
#      with [2l.tmac].
#
####################################/
function GROFF_INV
    { # BEGIN FUNC
    groff -m2l -Tlatin1 $1 > $2
    } # END FUNC
####################################\
#
#
#      <{V}> LATEX_to_RTF
#
#      This  function goes into [_] and uses [latex2rtf]. If you want to do
#      that manually, e.g. after having changed the latexfile, comment  its
#      invokation out (sect. [B]).
#
####################################/
function LATEX_to_RTF
    { # BEGIN FUNC
            latex2rtf $1
    } # END FUNC
####################################\
#
#
#    <[B]> INVOKATION
#
#      Now  we invoke the functions. I stuffed all the output in the [./_/]
#      subdirectory. If you don't want that, comment the  [U_DIR]  and  the
#      [$OUT_PATH] out. If anything goes wrong, you can check the files and
#      see where the flaw is. E.g. the [GETPN] macro  works  in  the  latex
#      file, but not in the rtf version.
#        If you are happy with the defaults, invoke [inv2l.sh *.mm].
#
####################################/
U_DIR
#
for IN_FILE in "$@" ; do
    OUT_PATH=./_/
    MM_RENAME
    cp $IN_FILE $OUT_PATH
    cd $OUT_PATH
    TEX_PREPROC  $IN_FILE  $M2LFILE
    echo "m2l generated."
    GROFF_INV    $M2LFILE $TEXFILE
    echo "latexfile generated."
    latex -interaction=nonstopmode $TEXFILE
    latex -interaction=nonstopmode $TEXFILE
    echo "auxfile created."
    LATEX_to_RTF $TEXFILE
    echo "rtf generated."
    cd -
    echo "All done. Output is in [./_/]."
done
####################################\
#
#
#                                       [END OF FILE]
